import { decodeAuthToken } from '../../utils';
export class CoreoLoginComponent {
    constructor() {
        this.views = {
            'LOGIN': 0,
            'SIGNUP': 1
        };
        this.credentialProviders = [];
        this.oauthCbPath = '/auth/oauth';
        this.syncError = false;
        this.view = this.views.LOGIN;
        this.loginError = null;
        this.signupError = null;
        this.hasSignedUp = false;
        this.apiSrc = '';
        this.googleEnabled = false;
        this.facebookEnabled = false;
        this.email = {
            valid: false,
            value: ''
        };
        this.password = {
            valid: false,
            value: ''
        };
        this.passwordConfirm = {
            valid: false,
            value: ''
        };
        this.displayName = {
            valid: false,
            value: ''
        };
        this.submitted = false;
    }
    componentWillLoad() {
        this.obtainCredentialProviders();
        if (this.apiCtrl) {
            this.apiCtrl.create().then((api) => {
                this.apiService = api;
                this.apiSrc = api.getSrc();
            });
        }
    }
    obtainCredentialProviders() {
        this.credentialProviders.map((provider) => {
            if (provider === 'google')
                this.googleEnabled = true;
            if (provider === 'facebook')
                this.facebookEnabled = true;
        });
    }
    passwordConfirmed() {
        return this.password.value === this.passwordConfirm.value;
    }
    localLogin(e) {
        e.preventDefault();
        this.submitted = true;
        this.loginStart.emit();
        const projectIdInput = this.projectId ? `, projectId: ${this.projectId}` : '';
        const query = `login(input:{email: "${this.email.value}", password: "${this.password.value}"${projectIdInput}}){token}`;
        this.apiService.graphql(query, 'mutation').then(({ data, errors }) => {
            if (errors) {
                this.loginError = errors[0].message;
                this.loginFail.emit(errors[0]);
                return;
            }
            const { login: { token } } = data;
            try {
                const decodedToken = decodeAuthToken(token);
                const data = {
                    token,
                    decodedToken
                };
                this.loginError = null;
                this.loginSuccess.emit(data);
            }
            catch (err) {
                this.loginFail.emit(err);
            }
        }, err => {
            this.loginError = 'There was an error siging in. Please check your credentials and try again';
            this.loginFail.emit(err);
        });
    }
    localSignup(e) {
        e.preventDefault();
        const query = `signup(input:{email: "${this.email.value}", password: "${this.password.value}", displayName: "${this.displayName.value}"}){
      user{
        id
      }
    }`;
        this.submitted = true;
        this.apiService.graphql(query, 'mutation').then(({ data, errors }) => {
            if (errors) {
                this.signupError = errors[0].message;
                return;
            }
            this.signupSuccess.emit(data);
            this.hasSignedUp = true;
        });
    }
    handleEmailChange(event) {
        const value = (event.target.value);
        this.email = {
            value,
            valid: value.length > 0
        };
    }
    handlePasswordChange(event) {
        const value = (event.target.value);
        this.password = {
            value,
            valid: value.length > 0
        };
    }
    handlePasswordConfirmChange(event) {
        const value = (event.target.value);
        console.log(value);
        this.passwordConfirm = {
            value,
            valid: value.length > 0
        };
    }
    handleDisplayNameChange(event) {
        const value = (event.target.value);
        this.displayName = {
            value,
            valid: value.length > 0
        };
    }
    renderOAuthButton(provider, projectId) {
        const label = provider.charAt(0).toUpperCase() + provider.slice(1);
        const returnUrl = `${window.location.origin}${this.oauthCbPath.startsWith('/') ? '' : '/'}${this.oauthCbPath}`;
        const url = `${this.apiSrc}/auth/${provider}?${projectId ? 'project_id=' + projectId + '&' : ''}return_url=${returnUrl}`;
        return h("ion-col", { size: "12" },
            " ",
            h("ion-button", { expand: "block", href: url, class: `btn-${provider}` },
                h("ion-icon", { slot: "start", name: 'logo-' + provider }),
                label));
    }
    renderSignIn() {
        const ready = this.email.valid && this.password.valid;
        const showError = this.submitted && this.loginError;
        return (h("form", { novalidate: "true", onSubmit: (e) => this.localLogin(e) },
            h("ion-list", { "no-lines": true },
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Email"),
                    h("ion-input", { inputmode: "email", required: true, type: "email", value: this.email.value, spellcheck: false, autocapitalize: "off", onIonInput: (ev) => this.handleEmailChange(ev) })),
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Password"),
                    h("ion-input", { inputmode: "password", minlength: 5, required: true, type: "password", value: this.password.value, onIonInput: (ev) => this.handlePasswordChange(ev) })),
                showError && h("ion-item", { lines: "none", "text-center": true },
                    h("ion-icon", { name: "alert", slot: "start" }),
                    this.loginError)),
            h("ion-row", null,
                h("ion-col", { size: "12" },
                    h("ion-button", { type: "submit", expand: "block", disabled: !ready, onClick: (e) => this.localLogin(e) }, "Login")),
                h("ion-col", { size: "12" },
                    h("ion-button", { expand: "block", fill: "solid", color: "light", onClick: () => this.goToSignup() }, "Sign Up")),
                (this.googleEnabled || this.facebookEnabled) && h("p", { class: "text-divider" },
                    h("span", null, "or")),
                this.googleEnabled && this.renderOAuthButton('google', this.projectId),
                this.facebookEnabled && this.renderOAuthButton('facebook', this.projectId))));
    }
    goToSignup() {
        this.view = this.views.SIGNUP;
        this.submitted = false;
        this.signupError = null;
    }
    cancelSignup() {
        this.view = this.views.LOGIN;
        this.password = {
            value: '',
            valid: false
        };
        this.email = {
            value: '',
            valid: false
        };
        this.submitted = false;
    }
    renderSignup() {
        const ready = this.email.valid && this.password.valid && this.passwordConfirm.valid && this.displayName.valid && this.password.value === this.passwordConfirm.value;
        const showError = this.submitted && this.signupError;
        return (h("form", { novalidate: "true", onSubmit: (e) => this.localSignup(e) },
            h("ion-list", { "no-lines": true },
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Email"),
                    h("ion-input", { inputmode: "email", value: this.email.value, required: true, type: "email", onIonInput: (ev) => this.handleEmailChange(ev) })),
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Password"),
                    h("ion-input", { inputmode: "password", value: this.password.value, minlength: 5, required: true, type: "password", onIonInput: (ev) => this.handlePasswordChange(ev) })),
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Confirm Password"),
                    h("ion-input", { inputmode: "password", value: this.passwordConfirm.value, minlength: 5, required: true, type: "password", onIonInput: (ev) => this.handlePasswordConfirmChange(ev) })),
                h("ion-item", null,
                    h("ion-label", { position: "floating" }, "Display Name"),
                    h("ion-input", { inputmode: "text", value: this.displayName.value, required: true, type: "text", onIonInput: (ev) => this.handleDisplayNameChange(ev) })),
                showError && h("ion-item", { lines: "none", "text-center": true },
                    h("ion-icon", { name: "alert", slot: "start" }),
                    this.signupError)),
            h("ion-row", null,
                h("ion-col", { size: "12" },
                    h("ion-button", { expand: "block", disabled: !ready, onClick: (e) => this.localSignup(e) }, "Sign Up")),
                h("ion-col", { size: "12" },
                    h("ion-button", { expand: "block", onClick: () => this.cancelSignup() }, "Cancel")))));
    }
    renderSignupSuccess() {
        return (h("ion-grid", null,
            h("ion-row", null,
                h("ion-col", { size: "12" }, "Thank you for signing up, please check your email for an account verification link.")),
            h("ion-row", null,
                h("ion-col", { size: "12" },
                    h("ion-button", { expand: "block", onClick: () => this.view = this.views.LOGIN }, "Return to Login")))));
    }
    render() {
        if (this.syncError) {
            return null;
        }
        switch (this.view) {
            case this.views.LOGIN:
                return this.renderSignIn();
            case this.views.SIGNUP:
                return this.hasSignedUp ? this.renderSignupSuccess() : this.renderSignup();
            default:
                return null;
        }
    }
    static get is() { return "coreo-login"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "apiSrc": {
            "state": true
        },
        "credentialProviders": {
            "type": "Any",
            "attr": "credential-providers"
        },
        "displayName": {
            "state": true
        },
        "el": {
            "elementRef": true
        },
        "email": {
            "state": true
        },
        "facebookEnabled": {
            "state": true
        },
        "googleEnabled": {
            "state": true
        },
        "hasSignedUp": {
            "state": true
        },
        "loginError": {
            "state": true
        },
        "oauthCbPath": {
            "type": String,
            "attr": "oauth-cb-path"
        },
        "password": {
            "state": true
        },
        "passwordConfirm": {
            "state": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "signupError": {
            "state": true
        },
        "submitted": {
            "state": true
        },
        "syncError": {
            "state": true
        },
        "view": {
            "state": true
        }
    }; }
    static get events() { return [{
            "name": "loginStart",
            "method": "loginStart",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "loginSuccess",
            "method": "loginSuccess",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "loginFail",
            "method": "loginFail",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "signupSuccess",
            "method": "signupSuccess",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return "/**style-placeholder:coreo-login:**/"; }
}
