export class CoreoProjectUserLeaderboardComponent {
    constructor() {
        this.limit = 10;
    }
    async componentWillLoad() {
        console.log('[coreo-project-user-leaderboard] componentWillLoad', this.projectId);
        if (!this.apiCtrl) {
            throw new Error("SyncError: Coreo API not found");
        }
        try {
            this.apiService = await this.apiCtrl.create();
            return this._update();
        }
        catch (err) {
            throw new Error(`SyncError: Coreo API error:\n" ${err}`);
        }
    }
    async _update() {
        const query = `
            project (id: ${this.projectId}) {
                leaderboard: leaderboard(limit: ${this.limit}) {
                    user {
                        displayName
                    }
                    recordCount
                    position
                }
            }
        `;
        try {
            const data = await this.apiService.graphql(query);
            this.leaderboard = data.data.project.leaderboard;
        }
        catch (error) {
            throw new Error(error);
        }
    }
    render() {
        if (!this.leaderboard || !this.leaderboard.length)
            return null;
        return (h("div", { class: "leaderboard" },
            h("dl", null, this.leaderboard.map(leaderboardEntry => {
                return h("div", { class: "leaderboard-entry" },
                    h("dt", null, leaderboardEntry.user.displayName),
                    h("dd", null, leaderboardEntry.recordCount));
            }))));
    }
    static get is() { return "coreo-project-user-leaderboard"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "el": {
            "elementRef": true
        },
        "leaderboard": {
            "state": true
        },
        "limit": {
            "type": Number,
            "attr": "limit"
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        }
    }; }
    static get style() { return "/**style-placeholder:coreo-project-user-leaderboard:**/"; }
}
