export class CoreoRecordAttributesComponent {
    constructor() {
        this.placeholderLength = 10;
        this.limit = null;
        this.syncError = false;
    }
    componentWillLoad() {
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._loadAttributes();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _loadAttributes() {
        this.apiService.graphql(`record(id: ${this.recordId}){data,attributes(where:{visible:true}, order: "order"){label,order,visible,field{path,type,collection{items {key,value}}}}}`).then(response => {
            const { attributes, data } = response.data.record;
            const limit = this.limit === null ? attributes.length : this.limit;
            this.recordAttributes = attributes
                .filter(a => a.visible)
                .sort((a, b) => a.order < b.order ? -1 : a.order > b.order ? 1 : 0)
                .slice(0, limit)
                .map(attribute => {
                let value;
                switch (attribute.field.type) {
                    case 'boolean': {
                        value = value === true ? 'Yes' : 'No';
                        break;
                    }
                    case 'select': {
                        let item = attribute.field.collection.items.find(a => a.key === data[attribute.field.path]);
                        if (item) {
                            value = item.value;
                        }
                        break;
                    }
                    case 'media': {
                        value = data[attribute.field.path] ? h("a", { href: `https://api.coreo.io/records/${this.recordId}/images/${attribute.field.path}` }, "View Image") : "";
                        break;
                    }
                    default: {
                        value = data[attribute.field.path];
                    }
                }
                return { label: attribute.label, type: attribute.field.type, value };
            });
        });
    }
    render() {
        if (this.syncError)
            return null;
        if (this.recordAttributes) {
            return (h("div", { class: "attributes-list" },
                h("dl", null, this.recordAttributes.map(a => {
                    if (this.hideMedia && a.type === "media") {
                        return null;
                    }
                    return (h("div", { class: "individual-attribute" + (a.type ? (" " + a.type) : "") },
                        h("dt", null, a.label),
                        h("dd", null, a.value)));
                }))));
        }
        else {
            return (h("div", { class: "attributes-list" },
                h("dl", null, Array(this.placeholderLength).fill(null).map(() => {
                    return h("div", { class: "individual-attribute" },
                        h("dt", null, "\u200C"),
                        h("dd", null, "\u200C"));
                }))));
        }
    }
    static get is() { return "coreo-record-attributes"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "hideMedia": {
            "type": Boolean,
            "attr": "hide-media"
        },
        "limit": {
            "type": Number,
            "attr": "limit"
        },
        "placeholderLength": {
            "type": Number,
            "attr": "placeholder-length"
        },
        "recordAttributes": {
            "state": true
        },
        "recordId": {
            "type": String,
            "attr": "record-id"
        },
        "syncError": {
            "state": true
        }
    }; }
    static get style() { return "/**style-placeholder:coreo-record-attributes:**/"; }
}
