export class CoreoRecordImageCoverComponent {
    constructor() {
        this.syncError = false;
    }
    componentWillLoad() {
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._loadImage();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _loadImage() {
        const query = `
            project(id: ${this.projectId}) {
                records(where: {id: ${this.recordId}}) {
                    attributes(where:{visible:true}) {
                        label
                        field {
                            path
                                type
                            }
                        }
                    data
                }
            }
        `;
        this.apiService.graphql(query).then(data => {
            const mediaAttributes = [];
            data.data.project.records[0].attributes.map(attribute => {
                if (attribute.field.type === 'media' && data.data.project.records[0].data[attribute.field.path]) {
                    mediaAttributes.push({
                        path: attribute.field.path,
                        label: attribute.label,
                        order: attribute.order,
                    });
                }
            });
            this.imageAttribute = mediaAttributes[0];
        });
    }
    render() {
        if (this.syncError)
            return null;
        let coverImage = null;
        if (this.imageAttribute && this.imageAttribute.path) {
            coverImage = (h("div", { class: "coreo-record-image-cover" },
                h("coreo-record-image", { "record-id": this.recordId, path: this.imageAttribute.path, alt: this.imageAttribute.label || "" })));
        }
        return coverImage;
    }
    static get is() { return "coreo-record-image-cover"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "el": {
            "elementRef": true
        },
        "imageAttribute": {
            "state": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "recordId": {
            "type": Number,
            "attr": "record-id"
        },
        "syncError": {
            "state": true
        }
    }; }
}
