export class CoreoRecordImageSliderComponent {
    constructor() {
        this.syncError = false;
        this.currentIndex = 0;
        this.slideInterval = 5000;
        this.move = (newIndex) => {
            this.advance();
            if (this.currentIndex === newIndex) {
                return;
            }
            this.previousIndex = this.currentIndex;
            this.currentIndex = newIndex;
        };
        this.advance = () => {
            clearTimeout(this.timeoutObj);
            this.timeoutObj = setTimeout(() => {
                if (this.currentIndex < this.imageAttributes.length - 1) {
                    this.move(this.currentIndex + 1);
                }
                else {
                    this.move(0);
                }
            }, this.slideInterval);
        };
        this.nextButtonHandler = () => {
            if (this.currentIndex < this.imageAttributes.length - 1) {
                this.move(this.currentIndex + 1);
            }
            else {
                this.move(0);
            }
        };
        this.previousButtonHandler = () => {
            if (this.currentIndex > 0) {
                this.move(this.currentIndex - 1);
            }
            else {
                this.move(this.imageAttributes.length - 1);
            }
        };
        this.slideButtonHandler = (newIndex) => {
            this.move(newIndex);
        };
    }
    componentWillLoad() {
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._loadImages();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _loadImages() {
        const query = `
            project(id: ${this.projectId}) {
                records(where: {id: ${this.recordId}}) {
                    attributes(where:{visible:true}) {
                        label
                        field {
                            path
                            type
                        }
                        order
                    }
                    data
                }
            }
        `;
        this.apiService.graphql(query).then(data => {
            const mediaAttributes = [];
            data.data.project.records[0].attributes.map(attribute => {
                if (attribute.field.type === 'media' && data.data.project.records[0].data[attribute.field.path]) {
                    mediaAttributes.push({
                        path: attribute.field.path,
                        label: attribute.label,
                        order: attribute.order,
                    });
                }
            });
            this.imageAttributes = mediaAttributes;
            if (this.imageAttributes) {
                this.advance();
            }
        });
    }
    render() {
        if (this.syncError)
            return null;
        const previousButtonSVG = (h("svg", { version: "1.1", xmlns: "http://www.w3.org/2000/svg", xmlnsXlink: "http://www.w3.org/1999/xlink", x: "0px", y: "0px", width: "65px", height: "65px", viewBox: "-11 -11.5 65 66" },
            h("g", null,
                h("g", null,
                    h("path", { fill: "#474544", d: "M-10.5,22.118C-10.5,4.132,4.133-10.5,22.118-10.5S54.736,4.132,54.736,22.118 c0,17.985-14.633,32.618-32.618,32.618S-10.5,40.103-10.5,22.118z M-8.288,22.118c0,16.766,13.639,30.406,30.406,30.406 c16.765,0,30.405-13.641,30.405-30.406c0-16.766-13.641-30.406-30.405-30.406C5.35-8.288-8.288,5.352-8.288,22.118z" }),
                    h("path", { fill: "#474544", d: "M25.43,33.243L14.628,22.429c-0.433-0.432-0.433-1.132,0-1.564L25.43,10.051c0.432-0.432,1.132-0.432,1.563,0\tc0.431,0.431,0.431,1.132,0,1.564L16.972,21.647l10.021,10.035c0.432,0.433,0.432,1.134,0,1.564\tc-0.215,0.218-0.498,0.323-0.78,0.323C25.929,33.569,25.646,33.464,25.43,33.243z" })))));
        const nextButtonSVG = (h("svg", { version: "1.1", xmlns: "http://www.w3.org/2000/svg", xmlnsXlink: "http://www.w3.org/1999/xlink", x: "0px", y: "0px", width: "65px", height: "65px", viewBox: "-11 -11.5 65 66" },
            h("g", null,
                h("g", null,
                    h("path", { fill: "#474544", d: "M22.118,54.736C4.132,54.736-10.5,40.103-10.5,22.118C-10.5,4.132,4.132-10.5,22.118-10.5\tc17.985,0,32.618,14.632,32.618,32.618C54.736,40.103,40.103,54.736,22.118,54.736z M22.118-8.288\tc-16.765,0-30.406,13.64-30.406,30.406c0,16.766,13.641,30.406,30.406,30.406c16.768,0,30.406-13.641,30.406-30.406 C52.524,5.352,38.885-8.288,22.118-8.288z" }),
                    h("path", { fill: "#474544", d: "M18.022,33.569c 0.282,0-0.566-0.105-0.781-0.323c-0.432-0.431-0.432-1.132,0-1.564l10.022-10.035 \t\t\tL17.241,11.615c 0.431-0.432-0.431-1.133,0-1.564c0.432-0.432,1.132-0.432,1.564,0l10.803,10.814c0.433,0.432,0.433,1.132,0,1.564 L18.805,33.243C18.59,33.464,18.306,33.569,18.022,33.569z" })))));
        let gallery = null;
        if (this.imageAttributes) {
            const previousSlideStyle = {};
            const currentSlideStyle = {
                display: 'block',
            };
            gallery = (h("div", { class: "slider" },
                h("div", { class: "slide-viewer" },
                    h("ul", { class: "slide-group" }, this.imageAttributes.map((image, index) => {
                        if (index === this.previousIndex) {
                            return h("li", { class: "slide", style: previousSlideStyle },
                                h("coreo-record-image", { "record-id": this.recordId, path: image.path, alt: "" }));
                        }
                        if (index === this.currentIndex) {
                            return h("li", { class: "slide", style: currentSlideStyle },
                                h("coreo-record-image", { "record-id": this.recordId, path: image.path, alt: "" }));
                        }
                        return h("li", { class: "slide" },
                            h("coreo-record-image", { "record-id": this.recordId, path: image.path, alt: "" }));
                    }))),
                h("div", { class: "navigation-buttons" },
                    h("div", { class: "previous-button", title: "Previous", onClick: () => this.previousButtonHandler() }, previousButtonSVG),
                    h("div", { class: "slide-buttons" }, this.imageAttributes.map((_image, index) => {
                        if (index === this.currentIndex) {
                            return h("a", { class: "slide-button active", onClick: () => this.slideButtonHandler(index) }, "\u2022");
                        }
                        return h("a", { class: "slide-button", onClick: () => this.slideButtonHandler(index) }, "\u2022");
                    })),
                    h("div", { class: "next-button", title: "Next", onClick: () => this.nextButtonHandler() }, nextButtonSVG))));
        }
        return gallery;
    }
    static get is() { return "coreo-record-image-slider"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "currentIndex": {
            "state": true
        },
        "el": {
            "elementRef": true
        },
        "imageAttributes": {
            "state": true
        },
        "previousIndex": {
            "state": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "recordId": {
            "type": Number,
            "attr": "record-id"
        },
        "slideInterval": {
            "type": Number,
            "attr": "slide-interval"
        },
        "syncError": {
            "state": true
        },
        "timeoutObj": {
            "state": true
        }
    }; }
    static get style() { return "/**style-placeholder:coreo-record-image-slider:**/"; }
}
