export class CoreoError extends Error {
    constructor(msg, code) {
        super(msg);
        this.code = code;
    }
}
const handleFetchErrors = (response) => {
    if (!response.ok) {
        return response.json().then(data => {
            if (data.msg && data.code) {
                throw new CoreoError(data.msg, data.code);
            }
            throw Error(response.statusText);
        });
    }
    return response.json();
};
export class CoreoAPIService {
    constructor(token, src = 'https://api.coreo.io', graphqlEndpoint = '/graphql') {
        this.token = token;
        this.src = src;
        this.graphqlEndpoint = graphqlEndpoint;
    }
    setToken(token) {
        this.token = token;
    }
    getToken() {
        return this.token;
    }
    setSrc(src) {
        this.src = src;
    }
    getSrc() {
        return this.src;
    }
    graphql(query, operation = 'query') {
        const options = {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json'
            },
            body: JSON.stringify({
                query: `${operation}{ ${query} }`
            })
        };
        if (this.token) {
            options.headers.Authorization = `JWT ${this.token}`;
        }
        return fetch(`${this.src}${this.graphqlEndpoint}`, options).then(handleFetchErrors);
    }
    post(path, body, isJson = false) {
        const options = {
            method: 'POST',
            body,
            headers: {
                'Authorization': `JWT ${this.token}`,
            }
        };
        if (isJson) {
            options.headers['Content-Type'] = 'application/json;charset=UTF-8';
        }
        return fetch(`${this.src}${path}`, options).then(handleFetchErrors);
    }
    get(path) {
        const options = {
            method: 'GET',
            headers: {
                'Authorization': `JWT ${this.token}`
            }
        };
        return fetch(`${this.src}${path}`, options).then(handleFetchErrors);
    }
}
