/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { b as parseIds } from './chunk-eb3c5f6a.js';

class CoreoRecordCardComponent {
    constructor() {
        this.photoField = 'photo';
    }
    componentWillLoad() {
        this.apiCtrl.create().then(api => api.graphql(`record(id: ${this.recordId}){ id,createdAt,data,user{displayName},survey{attributes(limit: 5){label,order,field{path}}} }`).then(response => this.record = response.data.record));
    }
    render() {
        if (!this.record) {
            return;
        }
        const { data, createdAt, survey: { attributes }, user: { displayName } } = this.record;
        const img = data[this.photoField];
        return (h("div", { class: "record" },
            h("div", { class: "thumb" },
                h("img", { src: img, alt: "thumbnail" })),
            h("div", { class: "details" },
                h("a", { href: "#", class: "view" }, "View record"),
                h("p", { class: "date" }, createdAt),
                h("p", null,
                    "Submitted by ",
                    displayName),
                h("ul", null, attributes.map(attribute => {
                    return h("li", null,
                        h("span", null, attribute.label),
                        data[attribute.field.path]);
                })))));
    }
    static get is() { return "coreo-record-card"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "photoField": {
            "type": String,
            "attr": "photo-field"
        },
        "record": {
            "state": true
        },
        "recordId": {
            "type": String,
            "attr": "record-id"
        }
    }; }
    static get style() { return "coreo-record-card .record{display:-webkit-box;display:-webkit-flex;display:-moz-flex;display:-ms-flexbox;display:flex;-webkit-box-shadow:0 6px 16px 0 rgba(0,0,0,.15);-moz-box-shadow:0 6px 16px 0 rgba(0,0,0,.15);box-shadow:0 6px 16px 0 rgba(0,0,0,.15);-moz-border-radius:5px;-webkit-border-radius:5px;border-radius:5px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;background:#eef2f4;padding:1rem;width:49%;position:relative;margin-bottom:1rem}coreo-record-card .record .thumb{width:25%}coreo-record-card .record .thumb img{width:100%;height:auto}coreo-record-card .record .details{width:75%;padding-left:5%;font-size:.75rem;line-height:1.6em}\@media (min-width:320px){coreo-record-card .record .details{font-size:calc(.75rem + .3125vw + -1px)}}\@media (min-width:960px){coreo-record-card .record .details{font-size:calc(.75rem + 2px)}}coreo-record-card .record .details .view{position:absolute;display:block;right:1rem;top:1rem;padding:5px 15px;color:#fff;background-color:#51808f;-moz-border-radius:6px;-webkit-border-radius:6px;border-radius:6px;-moz-background-clip:padding;-webkit-background-clip:padding-box;background-clip:padding-box;font-size:.75rem;line-height:1.4em}\@media (min-width:320px){coreo-record-card .record .details .view{font-size:calc(.75rem + .625vw + -2px)}}\@media (min-width:960px){coreo-record-card .record .details .view{font-size:calc(.75rem + 4px)}}coreo-record-card .record .details .view:active,coreo-record-card .record .details .view:hover{background-color:#34b8c1;color:#fff}coreo-record-card .record .details p{margin-bottom:.5rem}coreo-record-card .record .details .date{margin-bottom:1rem;margin-top:.5rem}coreo-record-card .record .details ul{padding:0;margin:0 0 .5rem}coreo-record-card .record .details ul li{padding:0;margin:0;display:block;font-weight:600}coreo-record-card .record .details ul li span{font-weight:300;margin-right:8px}coreo-record-card .record .details ul li:before{display:none}\@media (max-width:750px){coreo-record-card .records .record{width:100%}}"; }
}

class CoreoRecordCardsComponent {
    constructor() {
        this.limit = 10;
        this.records = [];
    }
    componentWillLoad() {
        let surveyIds = parseIds(this.surveyId);
        this.apiCtrl.create().then(api => api.graphql(`records( limit: ${this.limit}, where: { surveyId: { in: [ ${surveyIds.join(',')}] }}){ id,createdAt,data,user{displayName},survey{attributes(limit: 5){label,order,field{path}}} }`).then(response => this.records = response.data.records));
    }
    render() {
        if (!this.records.length) {
            return;
        }
        console.log('HERE', this.records);
        return this.records.map(record => h("coreo-record-card", { "record-id": record.id }));
    }
    static get is() { return "coreo-record-cards"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "limit": {
            "type": Number,
            "attr": "limit"
        },
        "records": {
            "state": true
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        }
    }; }
}

export { CoreoRecordCardComponent as CoreoRecordCard, CoreoRecordCardsComponent as CoreoRecordCards };
