/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

class CoreoMapComponent {
    constructor() {
        this.syncError = false;
        this.coreoMapLayers = [];
    }
    registerLayerHandler(event) {
        this.coreoMapLayers.push(event.detail);
    }
    async getMap() {
        return this.map;
    }
    componentDidLoad() {
        if (typeof L === 'undefined') {
            console.error("SyncError: Could not initialise map");
            this.syncError = true;
            return;
        }
        this.map = L.map(this.el);
        const bounds = L.latLngBounds([]);
        const controls = L.control.layers([], []);
        let baseLayerAdded = false;
        Promise.all(this.coreoMapLayers.map(layer => layer.promise)).then(() => {
            this.coreoMapLayers.forEach(coreoLayer => {
                let layer = coreoLayer.layer;
                if (coreoLayer.type === 'base') {
                    controls.addBaseLayer(layer, coreoLayer.title);
                    if (!baseLayerAdded) {
                        this.map.addLayer(layer);
                        baseLayerAdded = true;
                    }
                }
                else {
                    this.map.addLayer(layer);
                    bounds.extend(layer.getBounds());
                    controls.addOverlay(layer, coreoLayer.title);
                }
            });
            if (bounds.isValid()) {
                this.map.fitBounds(bounds);
            }
            controls.addTo(this.map);
        });
    }
    render() {
        if (this.syncError)
            return null;
        return false;
    }
    static get is() { return "coreo-map"; }
    static get properties() { return {
        "el": {
            "elementRef": true
        },
        "getMap": {
            "method": true
        },
        "projectId": {
            "type": String,
            "attr": "project-id"
        },
        "syncError": {
            "state": true
        }
    }; }
    static get listeners() { return [{
            "name": "registerLayer",
            "method": "registerLayerHandler"
        }]; }
    static get style() { return "coreo-map{min-height:480px;display:block}"; }
}

export { CoreoMapComponent as CoreoMap };
