/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

class CoreoForm {
    constructor() {
        this.attrs = [];
    }
    componentWillLoad() {
        this.apiCtrl.create().then(api => {
            this.apiService = api;
            this.loadForm();
        });
    }
    componentDidLoad() {
        this.form = this.el.querySelector('form');
    }
    loadForm() {
        console.log('Loading form');
        let query = `project(id:${this.projectId}){
            surveys{
              id,
              name,
              attributes{
                label,
                required,
                order,
                visible,
                field {
                  id,
                  type,
                  path,
                  meta,
                  collection{
                    sortField,
                    sortReverse,
                    items{
                      id,
                      key,
                      value,
                      data
                    }
                  }
                }
              }
            }
          }`;
        this.apiService.graphql(query).then(response => {
            const { data: { project: { surveys } } } = response;
            const survey = surveys.find(s => +s.id === +this.surveyId);
            if (!survey) {
                console.warn('Survey not found');
                return;
            }
            this.attrs = survey.attributes;
        });
    }
    renderAttribute(attribute) {
        const { label, required, field: { path, type } } = attribute;
        let input;
        const name = `data[${path}]`;
        switch (type) {
            case 'select': {
                const { field: { collection: { items } } } = attribute;
                input = (h("select", { name: name, required: required }, items.map(item => h("option", { value: item.key }, item.value))));
                break;
            }
            case 'integer':
            case 'float': {
                input = h("input", { required: required, name: name, type: "number" });
                break;
            }
            case 'media': {
                input = h("input", { required: required, name: name, type: "file", accept: "image/*" });
                break;
            }
            case 'text': {
                input = h("textarea", { required: required, name: name });
                break;
            }
            case 'datetime': {
                const now = new Date().toISOString().substr(0, 16);
                input = h("input", { required: required, value: now, type: "datetime-local", name: name, id: path });
                break;
            }
            default: {
                console.log('Default for', type);
                input = h("input", { required: required, type: "text", name: name, id: path });
            }
        }
        return (h("div", { class: 'coreo-form-field ' + (required ? 'required' : '') },
            h("label", { htmlfor: path }, label),
            input));
    }
    handleSubmit(e) {
        e.preventDefault();
        const data = new FormData(this.form);
        this.apiService.post('/records', data).then(result => {
            this.recordSubmitSuccess.emit(result);
        }, error => {
            this.recordSubmitFailure.emit(error);
        });
    }
    render() {
        return (h("form", { enctype: "multipart/form-data", onSubmit: (e) => this.handleSubmit(e) },
            h("fieldset", null, this.attrs.map(attribute => this.renderAttribute(attribute))),
            h("input", { type: "hidden", name: "projectId", value: this.projectId }),
            h("input", { type: "hidden", name: "surveyId", value: this.surveyId }),
            h("button", { type: "submit" }, "Submit")));
    }
    static get is() { return "coreo-form"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "attrs": {
            "state": true
        },
        "el": {
            "elementRef": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "surveyId": {
            "type": Number,
            "attr": "survey-id"
        }
    }; }
    static get events() { return [{
            "name": "recordSubmitSuccess",
            "method": "recordSubmitSuccess",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "recordSubmitFailure",
            "method": "recordSubmitFailure",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
}

export { CoreoForm };
