/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

class CoreoRecordListComponent {
    constructor() {
        this.syncError = false;
        this.limit = 10;
        this.order = "reverse:createdAt";
    }
    recordClickedHandler(recordId) {
        this.recordClicked.emit({ recordId: recordId });
    }
    componentWillLoad() {
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._update();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _update() {
        const surveyQuery = this.surveyId ? `, surveyId: ${this.surveyId}` : '';
        const parentIdQuery = this.parentId ? `, parentId: ${this.parentId}` : '';
        let timeframeQuery = '';
        if (this.timeframe) {
            const currentDate = new Date();
            let timeframeQueryDate = new Date();
            timeframeQueryDate.setDate(currentDate.getDate() - this.timeframe);
            timeframeQuery = `, createdAt:{gte:"${timeframeQueryDate}"}`;
        }
        const verificationStateQuery = this.verified ? `, state: 5` : '';
        const where = `where:{ projectId: ${this.projectId} ${surveyQuery} ${parentIdQuery} ${timeframeQuery} ${verificationStateQuery} }`;
        const query = `
            project(id: ${this.projectId}) {
                records(${where}, limit: ${this.limit}, order: "${this.order}") {
                    id
                    createdAt
                    user {
                        displayName
                    }
                }
            }
        `;
        this.apiService.graphql(query).then(data => {
            this.records = data.data.project.records;
        });
    }
    render() {
        if (this.syncError)
            return null;
        let recordList = null;
        if (this.records) {
            recordList = h("div", { class: "record-list" },
                h("ul", null, this.records.map(record => {
                    return (h("li", { class: "record-list-item", onClick: () => this.recordClickedHandler(record.id) },
                        h("ul", null,
                            h("li", { class: "record-list-item-element" }, record.id),
                            h("li", { class: "record-list-item-element" }, record.user.displayName),
                            h("li", { class: "record-list-item-element" }, record.createdAt))));
                })));
        }
        else {
            recordList = (h("div", { class: "record-list" },
                h("ul", null, Array(this.limit).fill(null).map(() => {
                    return (h("li", { class: "record-list-item" },
                        h("ul", null,
                            h("li", { class: "record-list-item-element" }, "\u200C"),
                            h("li", { class: "record-list-item-element" }, "\u200C"),
                            h("li", { class: "record-list-item-element" }, "\u200C"))));
                }))));
        }
        return recordList;
    }
    static get is() { return "coreo-record-list"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api "
        },
        "el": {
            "elementRef": true
        },
        "limit": {
            "type": Number,
            "attr": "limit"
        },
        "order": {
            "type": String,
            "attr": "order"
        },
        "parentId": {
            "type": Number,
            "attr": "parent-id"
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "records": {
            "state": true
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        },
        "syncError": {
            "state": true
        },
        "timeframe": {
            "type": Number,
            "attr": "timeframe"
        },
        "verified": {
            "type": Boolean,
            "attr": "verified"
        }
    }; }
    static get events() { return [{
            "name": "recordClicked",
            "method": "recordClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return ".record-list .record-list-item{display:block;overflow:auto;list-style:none}.record-list ul,li{margin-left:0;padding-left:0}"; }
}

export { CoreoRecordListComponent as CoreoRecordList };
