/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { b as parseIds } from './chunk-eb3c5f6a.js';

class CoreoMapPolylinesComponent {
    constructor() {
        this.groupKey = 'parentId';
    }
    componentWillLoad() {
        console.log('[coreo-map-polylines] componentWillLoad', this.projectId);
        let surveyIds = parseIds(this.surveyId);
        const where = `where: { surveyId: { in: [${surveyIds.join(',')}]}, projectId: ${this.projectId} }`;
        const limit = 3000;
        const groupKey = this.groupKey === 'parentId' ? this.groupKey : `data(path: "${this.groupKey}")`;
        this.data = this.apiCtrl.create().then(api => api.graphql(`records(limit: ${limit}, order: "reverse:id", ${where}){
            lat,
            lng,
            groupKey: ${groupKey}
        }`)).then((result) => {
            let { data: { records } } = result;
            records = records.filter(record => !(record.lat === 0 && record.lng === 0));
            const grouped = {};
            for (let i = 0; i < records.length; i++) {
                const k = records[i].groupKey;
                if (!grouped.hasOwnProperty(k)) {
                    grouped[k] = [records[i]];
                }
                else {
                    grouped[k].push(records[i]);
                }
            }
            return grouped;
        });
    }
    componentDidLoad() {
        const layer = L.featureGroup([]);
        let promise = this.data.then((data) => {
            for (let k in data) {
                let records = data[k];
                layer.addLayer(L.polyline(records.map(record => [record.lat, record.lng])));
            }
        });
        this.registerLayer.emit({ layer, promise, title: this.layerTitle, type: "overlay" });
    }
    static get is() { return "coreo-map-polylines"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "el": {
            "elementRef": true
        },
        "groupKey": {
            "type": String,
            "attr": "group-key"
        },
        "layerTitle": {
            "type": String,
            "attr": "layer-title"
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        }
    }; }
    static get events() { return [{
            "name": "registerLayer",
            "method": "registerLayer",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
}

export { CoreoMapPolylinesComponent as CoreoMapPolylines };
