/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { b as parseIds } from './chunk-eb3c5f6a.js';

const recordMarker = L.Marker.extend({
    options: {
        recordId: null
    }
});
class CoreoMapMarkerclusterComponent {
    componentWillLoad() {
        console.log('[coreo-map-markercluster] componentWillLoad', this.projectId);
        let surveyIds = parseIds(this.surveyId);
        const surveyQuery = surveyIds.length ? `, surveyId: { in: [${surveyIds.join(',')}] }` : '';
        const parentIdQuery = this.parentId ? `, parentId: ${this.parentId}` : '';
        let timeframeQuery = '';
        if (this.timeframe) {
            const currentDate = new Date();
            let timeframeQueryDate = new Date();
            timeframeQueryDate.setDate(currentDate.getDate() - this.timeframe);
            timeframeQuery = `, createdAt:{gte:"${timeframeQueryDate}"}`;
        }
        const verificationStateQuery = this.verified ? `, state: 5` : '';
        const where = `where:{ projectId: ${this.projectId} ${surveyQuery} ${parentIdQuery} ${timeframeQuery} ${verificationStateQuery} }`;
        const limit = this.cluster ? 10000 : 1000;
        this.data = this.apiCtrl.create().then(api => api.graphql(`records(limit: ${limit}, ${where}){ id, lat, lng } `));
    }
    componentDidLoad() {
        console.log('[coreo-map-markercluster] componentDidLoad');
        const layer = this.cluster ? L.markerClusterGroup() : L.featureGroup([]);
        layer.on('click', marker => this.markerClicked.emit({ marker, recordId: marker.layer.options.recordId, title: this.layerTitle }));
        let promise = this.data.then((data) => {
            let records = data.data.records;
            records.forEach(record => layer.addLayer(new recordMarker(new L.LatLng(record.lat, record.lng), {
                recordId: record.id
            })));
        });
        this.registerLayer.emit({ layer, promise, title: this.layerTitle, type: "overlay" });
    }
    static get is() { return "coreo-map-markers"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "cluster": {
            "type": Boolean,
            "attr": "cluster"
        },
        "el": {
            "elementRef": true
        },
        "layerTitle": {
            "type": String,
            "attr": "layer-title"
        },
        "parentId": {
            "type": Number,
            "attr": "parent-id"
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        },
        "timeframe": {
            "type": Number,
            "attr": "timeframe"
        },
        "verified": {
            "type": Boolean,
            "attr": "verified"
        }
    }; }
    static get events() { return [{
            "name": "registerLayer",
            "method": "registerLayer",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "markerClicked",
            "method": "markerClicked",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get style() { return ""; }
}

export { CoreoMapMarkerclusterComponent as CoreoMapMarkers };
