/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { c as generateRandomString } from './chunk-eb3c5f6a.js';

class CoreoChartComponent {
    constructor() {
        this.canvasId = generateRandomString(16);
        this.syncError = false;
        this.dataHasLoaded = [];
        this.chartWillLoad = false;
        this.chartInitError = false;
        this.keyValueDatasets = [];
        this.numericalPairDatasets = [];
        this.cronologicalDatasets = [];
        this.defaultColors = [
            'rgba(230, 25, 75, 0.2)',
            'rgba(60, 180, 75, 0.2)',
            'rgba(255, 225, 25, 0.2)',
            'rgba(0, 130, 200, 0.2)',
            'rgba(245, 130, 48, 0.2)',
            'rgba(145, 30, 180, 0.2)',
            'rgba(70, 240, 240, 0.2)',
            'rgba(240, 50, 230, 0.2)',
            'rgba(210, 245, 60, 0.2)',
            'rgba(250, 190, 190, 0.2)',
            'rgba(0, 128, 128, 0.2)',
            'rgba(230, 190, 255, 0.2)',
            'rgba(170, 110, 40, 0.2)',
            'rgba(255, 250, 200, 0.2)',
            'rgba(128, 0, 0, 0.2)',
            'rgba(170, 255, 195, 0.2)',
            'rgba(128, 128, 0, 0.2)',
            'rgba(255, 215, 180, 0.2)',
            'rgba(0, 0, 128, 0.2)',
            'rgba(128, 128, 128, 0.2)',
            'rgba(230, 25, 75, 0.2)',
            'rgba(60, 180, 75, 0.2)',
            'rgba(255, 225, 25, 0.2)',
            'rgba(0, 130, 200, 0.2)',
            'rgba(245, 130, 48, 0.2)',
            'rgba(145, 30, 180, 0.2)',
            'rgba(70, 240, 240, 0.2)',
            'rgba(240, 50, 230, 0.2)',
            'rgba(210, 245, 60, 0.2)',
            'rgba(250, 190, 190, 0.2)',
            'rgba(0, 128, 128, 0.2)',
            'rgba(230, 190, 255, 0.2)',
            'rgba(170, 110, 40, 0.2)',
            'rgba(255, 250, 200, 0.2)',
            'rgba(128, 0, 0, 0.2)',
            'rgba(170, 255, 195, 0.2)',
            'rgba(128, 128, 0, 0.2)',
            'rgba(255, 215, 180, 0.2)',
            'rgba(0, 0, 128, 0.2)',
            'rgba(128, 128, 128, 0.2)'
        ];
    }
    validateSources(newValue, _oldValue) {
        const isBlank = (newValue == null);
        if (isBlank) {
            throw new Error('sources: required');
        }
    }
    componentWillLoad() {
        if (!this.sources) {
            this.chartInitError = true;
            return;
        }
        this.sources.map(_source => {
            if (this.type === 'bar' || this.type === 'pie') {
                this.keyValueDatasets.push(new Map());
            }
            if (this.type === 'scatter') {
                this.numericalPairDatasets.push(new Array());
            }
            if (this.type === 'line') {
                this.cronologicalDatasets.push(new Array());
            }
            this.dataHasLoaded.push(false);
        });
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._update();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _update() {
        if (this.type === 'bar' || this.type === 'pie') {
            this.initialiseLabels();
            this.sources.map((_source, sourceIndex) => {
                this.initialiseKeyValueDataset(sourceIndex);
            });
        }
        else if (this.type === 'scatter') {
            this.sources.map((_source, sourceIndex) => {
                this.initialiseNumericalPairDataset(sourceIndex);
            });
        }
        else if (this.type === 'line') {
            this.sources.map((_source, sourceIndex) => {
                this.initialiseLineDataset(sourceIndex);
            });
        }
    }
    initialiseLabels() {
        const labelsQuery = `
                project(id: ${this.projectId}) {
                    surveys(where: {id: ${this.sources[0].source.surveyId}}) {
                        attributes {
                            field(where: {type: "select", path: "${this.sources[0].chart.x}"}) {
                                collection {
                                    items {
                                        value
                                    }
                                }
                            }
                        }
                    }
                }
            `;
        this.apiService.graphql(labelsQuery).then(data => {
            if (data == null || data.data == null || data.data.project == null || data.data.project.surveys == null || data.data.project.surveys[0] == null || data.data.project.surveys[0].attributes == null) {
                this.labels = [];
            }
            else {
                const attributes = data.data.project.surveys[0].attributes;
                attributes.map(attribute => {
                    if (attribute.field) {
                        this.labels = attribute.field.collection.items.map(item => {
                            return item.value;
                        });
                    }
                });
            }
        });
    }
    initialiseKeyValueDataset(datasetIndex) {
        const datasetQuery = `
            project(id: ${this.projectId}) {
                surveys(where: {id: ${this.sources[datasetIndex].source.surveyId}}) {
                    attributes {
                        xfield: field(where: {type: "select", path: "${this.sources[datasetIndex].chart.x}"}) {
                            collection {
                                items {
                                    key
                                }
                            }
                        }
                    }
                }
                records(limit: 10000, where:{surveyId: ${this.sources[datasetIndex].source.surveyId}}) {
                    data
                }
            }
        `;
        this.apiService.graphql(datasetQuery).then(data => {
            if (data == null || data.data == null || data.data.project == null || data.data.project.surveys == null || data.data.project.surveys[0] == null || data.data.project.surveys[0].attributes == null) {
                this.chartInitError = true;
                return;
            }
            const attributes = data.data.project.surveys[0].attributes;
            attributes.map(attribute => {
                if (attribute.xfield) {
                    attribute.xfield.collection.items.map(item => {
                        this.keyValueDatasets[datasetIndex].set(item.key, 0);
                    });
                }
            });
            if (this.sources[datasetIndex].chart.y) {
                data.data.project.records.map((record) => {
                    const key = record.data[this.sources[datasetIndex].chart.x];
                    if (key && key !== "") {
                        this.keyValueDatasets[datasetIndex].set(key, (this.keyValueDatasets[datasetIndex].get(key) + Number(record.data[this.sources[datasetIndex].chart.y])));
                    }
                });
            }
            else {
                data.data.project.records.map((record) => {
                    const key = record.data[this.sources[datasetIndex].chart.x];
                    if (key && key !== "") {
                        this.keyValueDatasets[datasetIndex].set(key, (this.keyValueDatasets[datasetIndex].get(key) + 1));
                    }
                });
            }
            this.dataHasLoaded[datasetIndex] = true;
            this.checkIfChartLoaded();
        });
    }
    initialiseNumericalPairDataset(datasetIndex) {
        const datasetQuery = `
            project(id: ${this.projectId}) {
                records(limit: 10000, where:{surveyId: ${this.sources[datasetIndex].source.surveyId}}) {
                    data
                }
            }
        `;
        this.apiService.graphql(datasetQuery).then(data => {
            if (data == null || data.data == null || data.data.project == null || data.data.project.records == null || data.data.project.records.length === 0) {
                this.chartInitError = true;
                return;
            }
            data.data.project.records.map((record) => {
                this.numericalPairDatasets[datasetIndex].push({
                    x: record.data[this.sources[datasetIndex].chart.x],
                    y: record.data[this.sources[datasetIndex].chart.y]
                });
            });
            this.dataHasLoaded[datasetIndex] = true;
            this.checkIfChartLoaded();
        });
    }
    initialiseLineDataset(datasetIndex) {
        const datasetQuery = `
            project(id: ${this.projectId}) {
                records(limit: 10000, where:{surveyId: ${this.sources[datasetIndex].source.surveyId}}) {
                    data
                    createdAt
                }
            }
        `;
        this.apiService.graphql(datasetQuery).then(data => {
            if (data == null || data.data == null || data.data.project == null || data.data.project.records == null || data.data.project.records.length === 0) {
                this.chartInitError = true;
                return;
            }
            if (this.sources[datasetIndex].chart.x) {
                data.data.project.records.map((record) => {
                    this.cronologicalDatasets[datasetIndex].push({
                        t: new Date(record.data[this.sources[datasetIndex].chart.x]),
                        y: record.data[this.sources[datasetIndex].chart.y]
                    });
                });
            }
            else {
                data.data.project.records.map((record) => {
                    this.cronologicalDatasets[datasetIndex].push({
                        t: new Date(record.createdAt),
                        y: Number(record.data[this.sources[datasetIndex].chart.y])
                    });
                });
            }
            this.dataHasLoaded[datasetIndex] = true;
            this.checkIfChartLoaded();
        });
    }
    checkIfChartLoaded() {
        let chartWillLoad = true;
        this.dataHasLoaded.forEach(chartLoaded => {
            chartWillLoad = chartLoaded && chartWillLoad;
        });
        this.chartWillLoad = chartWillLoad;
        if (this.chartWillLoad) {
            this.drawChart();
        }
    }
    drawChart() {
        switch (this.type) {
            case 'bar':
                this.drawBarChart();
                break;
            case 'pie':
                this.drawPieChart();
                break;
            case 'scatter':
                this.drawScatterChart();
                break;
            case 'line':
                this.drawLineChart();
                break;
            default:
                console.warn("Warning: Unrecognised chart type", this.type, ". No chart will be rendered.");
                this.chartInitError = true;
        }
    }
    drawBarChart() {
        const canvas = document.getElementById(this.canvasId);
        if (!(canvas instanceof HTMLCanvasElement))
            throw new Error(`Expected canvas to be an HTMLCanvasElement, was ${canvas && canvas.constructor && canvas.constructor.name || canvas}`);
        this.chartInitializationSuccess.emit();
    }
    drawPieChart() {
        const canvas = document.getElementById(this.canvasId);
        if (!(canvas instanceof HTMLCanvasElement))
            throw new Error(`Expected canvas to be an HTMLCanvasElement, was ${canvas && canvas.constructor && canvas.constructor.name || canvas}`);
        this.chartInitializationSuccess.emit();
    }
    drawScatterChart() {
        const canvas = document.getElementById(this.canvasId);
        if (!(canvas instanceof HTMLCanvasElement))
            throw new Error(`Expected canvas to be an HTMLCanvasElement, was ${canvas && canvas.constructor && canvas.constructor.name || canvas}`);
        this.chartInitializationSuccess.emit();
    }
    drawLineChart() {
        const canvas = document.getElementById(this.canvasId);
        if (!(canvas instanceof HTMLCanvasElement))
            throw new Error(`Expected canvas to be an HTMLCanvasElement, was ${canvas && canvas.constructor && canvas.constructor.name || canvas}`);
        this.chartInitializationSuccess.emit();
    }
    render() {
        if (this.syncError)
            return null;
        if (this.chartInitError) {
            this.chartInitializationError.emit();
            console.warn("Warning: Chart initialization error. Check chart configuration options and connection to Coreo.");
            return null;
        }
        return (h("div", { class: "coreo-chart" },
            this.chartWillLoad ? null : h("coreo-spinner", null),
            h("canvas", { id: this.canvasId })));
    }
    static get is() { return "coreo-chart"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "canvasId": {
            "type": String,
            "attr": "canvas-id"
        },
        "chart": {
            "state": true
        },
        "chartInitError": {
            "state": true
        },
        "chartWillLoad": {
            "state": true
        },
        "cronologicalDatasets": {
            "state": true
        },
        "dataHasLoaded": {
            "state": true
        },
        "defaultColors": {
            "state": true
        },
        "el": {
            "elementRef": true
        },
        "keyValueDatasets": {
            "state": true
        },
        "labels": {
            "state": true
        },
        "numericalPairDatasets": {
            "state": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "sources": {
            "type": "Any",
            "attr": "sources",
            "watchCallbacks": ["validateSources"]
        },
        "syncError": {
            "state": true
        },
        "type": {
            "type": String,
            "attr": "type"
        }
    }; }
    static get events() { return [{
            "name": "chartInitializationSuccess",
            "method": "chartInitializationSuccess",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "chartInitializationError",
            "method": "chartInitializationError",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
}

class CoreoSpinner {
    render() {
        return h("div", { class: "Loader" }, "Loading...");
    }
    static get is() { return "coreo-spinner"; }
    static get style() { return ".Loader,.Loader:after,.Loader:before{border-radius:50%}.Loader{color:#012b71;font-size:11px;text-indent:-99999em;margin:55px auto;position:relative;width:10em;height:10em;-webkit-box-shadow:inset 0 0 0 1em;box-shadow:inset 0 0 0 1em;-webkit-transform:translateZ(0);-ms-transform:translateZ(0);transform:translateZ(0)}.Loader:after,.Loader:before{position:absolute;content:\"\"}.Loader:before{border-radius:10.2em 0 0 10.2em;left:-.1em;-webkit-transform-origin:5.2em 5.1em;transform-origin:5.2em 5.1em;-webkit-animation:load2 2s ease 1.5s infinite;animation:load2 2s ease 1.5s infinite}.Loader:after,.Loader:before{width:5.2em;height:10.2em;background:#fff;top:-.1em}.Loader:after{border-radius:0 10.2em 10.2em 0;left:5.1em;-webkit-transform-origin:0 5.1em;transform-origin:0 5.1em;-webkit-animation:load2 2s ease infinite;animation:load2 2s ease infinite}\@-webkit-keyframes load2{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}\@keyframes load2{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}"; }
}

export { CoreoChartComponent as CoreoChart, CoreoSpinner };
