/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { b as parseIds } from './chunk-eb3c5f6a.js';

class CoreoRecordQueryComponent {
    constructor() {
        this.syncError = false;
    }
    componentWillLoad() {
        if (this.apiCtrl) {
            try {
                this.apiCtrl.create().then(api => {
                    this.apiService = api;
                    this._update();
                });
            }
            catch (error) {
                console.error("SyncError: Coreo API error:\n", error);
                this.syncError = true;
            }
        }
        else {
            console.error("SyncError: Coreo API not found");
            this.syncError = true;
        }
    }
    _update() {
        let path = this.path || '*';
        let fn = this.fn || 'COUNT';
        let distinct = typeof this.distinct === 'undefined' ? false : this.distinct;
        let surveyIds = parseIds(this.surveyId);
        const surveyQuery = surveyIds.length ? `, surveyId: { in: [${surveyIds.join(',')}] }` : '';
        const parentIdQuery = this.parentId ? `, parentId: ${this.parentId}` : '';
        let timeframeQuery = '';
        if (this.timeframe) {
            const currentDate = new Date();
            let timeframeQueryDate = new Date();
            timeframeQueryDate.setDate(currentDate.getDate() - this.timeframe);
            timeframeQuery = `, createdAt:{gte:"${timeframeQueryDate}"}`;
        }
        const verificationStateQuery = this.verified ? `, state: 5` : '';
        const where = `where:{ projectId: ${this.projectId} ${surveyQuery} ${parentIdQuery} ${timeframeQuery} ${verificationStateQuery} }`;
        const query = `
            result: recordsAggregate(function: "${fn}", path: "${path}", distinct: ${distinct}, ${where})
        `;
        this.apiService.graphql(query).then(result => {
            this.count = result.data.result;
        });
    }
    render() {
        if (this.syncError)
            return null;
        if (typeof this.count === 'undefined') {
            return (h("span", null, "\u200C"));
        }
        else {
            return (h("span", null, this.count));
        }
    }
    static get is() { return "coreo-record-query"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "count": {
            "state": true
        },
        "distinct": {
            "type": Boolean,
            "attr": "distinct"
        },
        "el": {
            "elementRef": true
        },
        "fn": {
            "type": String,
            "attr": "fn"
        },
        "parentId": {
            "type": Number,
            "attr": "parent-id"
        },
        "path": {
            "type": String,
            "attr": "path"
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        },
        "syncError": {
            "state": true
        },
        "timeframe": {
            "type": Number,
            "attr": "timeframe"
        },
        "verified": {
            "type": Boolean,
            "attr": "verified"
        }
    }; }
}

export { CoreoRecordQueryComponent as CoreoRecordQuery };
