/*! Built with http://stenciljs.com */
import { h } from '../coreo.core.js';

import { b as parseIds } from './chunk-eb3c5f6a.js';

class CoreoRecordTableComponent {
    constructor() {
        this.columns = [];
    }
    registerColumnHandler(event) {
        this.columns = [...this.columns, event.detail];
    }
    render() {
        console.log('[coreo-record-table] render', this.columns);
        if (!this.columns.length) {
            return;
        }
        const surveyIds = parseIds(this.surveyId);
        const columns = this.columns.map(column => column.attr);
        const builder = (record) => {
            return this.columns.map(column => {
                let target = record, attr = column.attr;
                if (column.attr.indexOf('.') !== -1) {
                    let t = column.attr.split('.');
                    target = record[t[0]];
                    attr = t[1];
                }
                return target[attr];
            });
        };
        const id = `coreo_record_table_${Date.now().toString()}`;
        setTimeout(() => {
            $(`#${id}`).DataTable({
                ajax: (_, callback) => {
                    this.apiCtrl.create().then(api => api.graphql(`records(where: { projectId: ${this.projectId}, surveyId: { in: [${surveyIds.join(',')}]} }){${columns.join(',')}, user { displayName }}`).then(response => {
                        return response.data.records.map(builder);
                    }).then(d => callback({ data: d })));
                }
            });
        });
        return (h("table", { id: id },
            h("thead", null,
                h("tr", null, this.columns.map(column => h("th", null, column.label)))),
            h("tfoot", null,
                h("tr", null, this.columns.map(column => h("th", null, column.label))))));
    }
    static get is() { return "coreo-record-table"; }
    static get properties() { return {
        "apiCtrl": {
            "connect": "coreo-api"
        },
        "columns": {
            "state": true
        },
        "el": {
            "elementRef": true
        },
        "projectId": {
            "type": Number,
            "attr": "project-id"
        },
        "surveyId": {
            "type": String,
            "attr": "survey-id"
        }
    }; }
    static get listeners() { return [{
            "name": "registerColumn",
            "method": "registerColumnHandler"
        }]; }
}

export { CoreoRecordTableComponent as CoreoRecordTable };
